@@ -150,7 +150,7 @@ void TimeAdminDialog::saveChangesToSystem()
             }
         }
     }
-#ifdef Q_OS_FREEBSD
+#if defined  Q_OS_FREEBSD || defined NO_SYSTEMD
     mTimeDateCtl.pkexec();
     if(modified.testFlag(DateTimePage::M_LOCAL_RTC)) {
     const QString infoMsg = mDateTimeWidget->localRtc() ?  tr("Change RTC to be in localtime requires a reboot") : tr("Change RTC to be in UTC requires a reboot");
